# PaymentMethodType

The type of payment method.

## Enum

* `ACH` (value: `'ACH'`)

* `APPLEPAY` (value: `'ApplePay'`)

* `BANKTRANSFER` (value: `'BankTransfer'`)

* `CASH` (value: `'Cash'`)

* `CHECK` (value: `'Check'`)

* `CREDITCARD` (value: `'CreditCard'`)

* `CREDITCARDREFERENCETRANSACTION` (value: `'CreditCardReferenceTransaction'`)

* `DEBITCARD` (value: `'DebitCard'`)

* `OTHER` (value: `'Other'`)

* `PAYPAL` (value: `'PayPal'`)

* `WIRETRANSFER` (value: `'WireTransfer'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


